Rhizom
======

Rhizom is a web application that can display efficiently a network of relationships.

It is based on [Flask](http://flask.pocoo.org/), and the graph is displayed
using [D3.js](http://d3js.org/).

Authentication is handled by [Mozilla Persona](http://persona.org).

Rhizom is licensed under the [Affero GPL
v3](http://www.gnu.org/licenses/agpl-3.0.html) or any later version.
